@@ -2,7 +2,7 @@
 import pandas as pd
 import numpy as np
 
-def basic_table(read_type, sheet_name, read_path, columns_to_keep, columns_rename, filters, group_by, aggregate_columns):
+def basic_table(read_type, sheet_name, read_path, columns_to_keep, columns_rename, filters, group_by, aggregate_columns, pre_agg_math_columns, post_agg_math_columns):
     
     if read_type == 'csv':
         df_basic_table = pd.read_csv(read_path)
@@ -13,6 +13,10 @@ def basic_table(read_type, sheet_name, read_path, columns_to_keep, columns_renam
     
     df_basic_table = df_basic_table[columns_to_keep]
     df_basic_table.columns = columns_rename
+
+    if pre_agg_math_columns != "":
+        for new_column_name, math_expression in pre_agg_math_columns.items():
+            df_basic_table[new_column_name] = df_basic_table.eval(math_expression)
     
     for column, operator, value in filters:
         if operator == "==":
@@ -30,6 +34,11 @@ def basic_table(read_type, sheet_name, read_path, columns_to_keep, columns_renam
 
     df_basic_table = df_basic_table.groupby(group_by).aggregate(aggregate_columns).reset_index()
 
+    if post_agg_math_columns != "":
+        for new_column_name, math_expression in post_agg_math_columns.items():
+            df_basic_table[new_column_name] = df_basic_table.eval(math_expression)
+
+
     return df_basic_table
 
 
